@@ -5,16 +5,12 @@
 """Global objects with the content of the microarchitecture
 JSON file and its schema
 """
+import collections.abc
 import json
 import os.path
 
-try:
-    from collections.abc import MutableMapping  # novm
-except ImportError:
-    from collections import MutableMapping  # pylint: disable=deprecated-class
 
-
-class LazyDictionary(MutableMapping):
+class LazyDictionary(collections.abc.MutableMapping):
     """Lazy dictionary that gets constructed on first access to any object key
 
     Args:
@@ -56,7 +52,7 @@ def _load_json_file(json_file):
 
     def _factory():
         filename = os.path.join(json_dir, json_file)
-        with open(filename, "r") as file:  # pylint: disable=unspecified-encoding
+        with open(filename, "r", encoding="utf-8") as file:
             return json.load(file)
 
     return _factory
